# reportlab-stubs

[![Release Package](
  https://github.com/eggplants/reportlab-stubs/actions/workflows/release.yml/badge.svg
  )](
  https://github.com/eggplants/reportlab-stubs/actions/workflows/release.yml
) [![PyPI](
  https://img.shields.io/pypi/v/reportlab-stubs?color=blue
  )](
  https://pypi.org/project/reportlab-stubs/
) [![pre-commit.ci status](
  https://results.pre-commit.ci/badge/github/eggplants/reportlab-stubs/master.svg
  )](
  https://results.pre-commit.ci/latest/github/eggplants/reportlab-stubs/master
)

Typing stubs for [ReportLab](https://www.reportlab.com)
